drvconfig(8) 맨 페이지 - 윈디하나의 솔라나라

개요

섹션
맨 페이지 이름
검색(S)

drvconfig(8)

drvconfig(8)            System Administration Commands            drvconfig(8)

NAME
       drvconfig - apply permission and ownership changes to devices

SYNOPSIS
       drvconfig [-bn] [-a alias_name] [-c class_name]
            [-i drivername] [-m major_num] [-r root_dir]

DESCRIPTION
       devfsadm(8)  is now the preferred command and should be used instead of
       drvconfig.


       The default operation of drvconfig is to apply permission and ownership
       changes to devices. Normally, this command is run automatically after a
       new driver has been installed (with add_drv(8)) and the system has been
       rebooted.

OPTIONS
       The following options are supported:

       -aalias_name    Add the name alias_name to the  list  of  aliases  that
                       this  driver is known by. This option, if used, must be
                       used with the -m  major_num, the -b and the -i  driver‐
                       name options.


       -b              Add a new major number to name binding  into  the  ker‐
                       nel's internal name_to_major tables. This option is not
                       normally  used directly, but is used by other utilities
                       such as add_drv(8). Use of the -b option requires  that
                       -i  and  -m  be used also. No /devices entries are cre‐
                       ated.


       -cclass_name    The driver being added to the system exports the  class
                       class_name.  This option is not normally used directly,
                       but is used by other utilities. It  is  only  effective
                       when used with the -b option.


       -idrivername    Only  configure  the  devices for the named driver. The
                       following options are used  by  the  implementation  of
                       add_drv(8)  and rem_drv(8), and may not be supported in
                       future versions of Solaris:


       -mmajor_num     Specify the major number major_num for this  driver  to
                       add to the kernel's name_to_major binding tables.


       -n              Do not try to load and attach any drivers, or if the -i
                       option  is given, do not try to attach the driver named
                       drivername.


       -rroot_dir      Perform operations under root_dir, rather than directly
                       under root.


EXIT STATUS
       0           Successful completion.


       non-zero    An error occurred.


FILES
       /devices               Device nodes directory


       /etc/minor_perm        Minor mode permissions


       /etc/name_to_major     Major number binding


       /etc/driver_classes    Driver class binding file


ATTRIBUTES
       See attributes(7) for descriptions of the following attributes:

       tab() box; cw(2.75i) |cw(2.75i) lw(2.75i) |lw(2.75i) ATTRIBUTE  TYPEAT‐
       TRIBUTE VALUE _ Availabilitysystem/device-administration


SEE ALSO
       sh(1),  devfs(4FS),  path_to_inst(5),  attributes(7),  add_drv(8), mod‐
       info(8), modload(8), modunload(8), rem_drv(8), update_drv(8)

Oracle Solaris 11.4               11 Aug 2014                     drvconfig(8)
맨 페이지 내용의 저작권은 맨 페이지 작성자에게 있습니다.
RSS ATOM XHTML 5 CSS3